# rmtoo-art-version1

NAME
DESCRIPTION
CONFIGURATION
SEE ALSO
AUTHOR
COPYRIGHT

## NAME

rmtoo-art-version1 - requirements management tool: version1 artifact

## DESCRIPTION

The rmtoo requirment management tool is able to output a file with the actual used version id. This version id can be used in different output documents to get a unique reference to the used requirement set version.

The version id itself is taken from the underlaying version control system. Different version control system have different version ids.

## CONFIGURATION

The name must be set to version1. The following parameters must be included in the map:

output_filename The parameter is the name of the file where the version information will be stored.

## SEE ALSO

rmtoo(7) - overview of rmtoo including all references to available documentation.

## AUTHOR

Written by Andreas Florath (rmtoo@florath.net)

## COPYRIGHT

Copyright © 2010-2011 by flonatel (rmtoo@florath.net). License GPLv3+: GNU GPL version 3 or later